@@ -32,7 +32,7 @@ class SubscriptionRequest(models.Model):
     )
     discovery_channel = fields.Selection(
         selection = [
-            ('boca', _('Boca a boca')),
+            ('boca', _('Boca-orella')),
             ('fulleto', _('Fulletó')),
             ('radio', _('Ràdio')),
             ('tv', _('TV')),
